# Learning

Building Wasot is for fun and learning.
Thus I do things that are interesting and to learn things.

For reflections on the AI-assisted development process, see [a note on vibe coding](./a_note_on_vibe_coding.md). For the design philosophy, see [principles](./principles.md).

Interesting things include:

- PGO (see [build release](./build_release.md))
- Writing the initial version in Go
- Rewriting in Rust
- Vibe-Coding for code generation
- Building a [CLI tool](./cli.md)
- Building different parsers
- Learning about Treesitter and LSPs
- Working with files bigger than RAM using [events](./architecture.md) (see [memory analysis](./memory_analysis.md))
- ... and so much more